# Assess dependence of SBW and MBW upon area

#library(xlsx)
library(ggplot2)
library(reshape2)
DATA = read.csv('Test_SBW_MBW_v2 copia.csv', header =TRUE, sep =';')
# DATA <- read.xlsx('Test_SBW_MBW_v2.xlsx', 1, rowIndex = 1:73)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# NOTE: it looks like some data rows are misaligned.
# 1. Should the SBW.Incompta column be shifted up from row 49 downwards?
# 2. In column SBW.Truncat, row 49 is unmatched to other data.
# Has something happened to perturb the data at row 49?
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Subset data by species
bull <- subset(DATA, select = c(Area, SBW.Bulloides, MBW.Bulloides))
incompta <- subset(DATA, select = c(Area.1, SBW.Incompta, MBW.Incompta))
truncat <- subset(DATA, select = c(Area.2, SBW.Truncat, MBW.Truncat))
names(bull) <- c('area','sbw','mbw')
names(incompta) <- c('area','sbw','mbw')
names(truncat) <- c('area','sbw','mbw')
bull$species <- 'bull'
incompta$species <- 'incompta'
truncat$species <- 'truncat'
bull$sbw = as.numeric(bull$sbw)
bull$mbw = as.numeric(bull$mbw)
incompta$sbw = as.numeric(incompta$sbw)
incompta$mbw = as.numeric(incompta$mbw)
truncat$sbw = as.numeric(truncat$sbw)
truncat$mbw = as.numeric(truncat$mbw)

# Merge data into long-form
dat <- rbind(bull, incompta, truncat)
dat$species <- as.factor(dat$species)
dat <- melt(dat, id.vars = c('species','area'),
            variable.name = 'measure', value.name = 'weight')

head(dat)
dat$weight = as.numeric(dat$weight)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Plot the data
plt1 <- ggplot(data = dat, aes(x = area, y = weight)) + 
  geom_point() + 
  facet_wrap(vars(measure, species), scales = 'free', nrow = 2) +
  ggtitle('Scatter plot of raw data: weight vs area',
          subtitle = 'Raw weights on top row; transformed weights on bottom row') +
  theme_bw()
plt1

# As expected, the SBW measurements appear to increase with area, while MBW
# appears independent of area.

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Pearson correlation tests

# Generate test values
ct_bull_sbw <- cor.test(bull$area, bull$sbw)
ct_bull_mbw <- cor.test(bull$area, bull$mbw)
ct_incompta_sbw <- cor.test(incompta$area, incompta$sbw)
ct_incompta_mbw <- cor.test(incompta$area, incompta$mbw)
ct_truncat_sbw <- cor.test(truncat$area, truncat$sbw)
ct_truncat_mbw <- cor.test(truncat$area, truncat$mbw)

# Extract results
cor_bull_sbw <- ct_bull_sbw$estimate
cor_bull_mbw <- ct_bull_mbw$estimate
corRange_bull_sbw <-ct_bull_sbw$conf.int
corRange_bull_mbw <-ct_bull_mbw$conf.int
cor_incompta_sbw <- ct_incompta_sbw$estimate
cor_incompta_mbw <- ct_incompta_mbw$estimate
corRange_incompta_sbw <-ct_incompta_sbw$conf.int
corRange_incompta_mbw <-ct_incompta_mbw$conf.int
cor_truncat_sbw <- ct_truncat_sbw$estimate
cor_truncat_mbw <- ct_truncat_mbw$estimate
corRange_truncat_sbw <-ct_truncat_sbw$conf.int
corRange_truncat_mbw <-ct_truncat_mbw$conf.int

# Examine results
printOutput <- function(cor, r, species, measure){
  print(paste0('Correlation of ', species, ' ', measure, ' with area is ', signif(cor,2), ' within confidence interval of (', signif(r[1],2), ', ', signif(r[2],2), ').'))
  if(r[1] < 0 & r[2] > 0){
    print('This correlation is not significant.')}else{
      print('This is a significant correlation.')}
}

printOutput(cor_bull_sbw, corRange_bull_sbw, 'Bulloides', 'SBW')
printOutput(cor_bull_mbw, corRange_bull_mbw, 'Bulloides', 'MBW')

printOutput(cor_incompta_sbw, corRange_incompta_sbw, 'Incompta', 'SBW')
printOutput(cor_incompta_mbw, corRange_incompta_mbw, 'Incompta', 'MBW')

printOutput(cor_truncat_sbw, corRange_truncat_sbw, 'Truncat', 'SBW')
printOutput(cor_truncat_mbw, corRange_truncat_mbw, 'Truncat', 'MBW')

# The above print-outs are all we need. The results are as we expected.
# Below is additional code for linear modelling, but this is not needed.

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Linear modelling

# We may expect SBW to vary linearly with volume. Volume should be proportional
# to area ^ (3/2). Thus, SWB ~ area ^ (3/2), or SWB ^ (2/3) ~ area.

# 1. Bulloides

bull$sbw2 <- bull$sbw ^ {2/3}

plt.bull.1 <- ggplot(bull, aes(x = area, y = sbw)) +
  geom_point()
plt.bull.2 <- ggplot(bull, aes(x = area, y = sbw2)) +
  geom_point()

plt.bull.1
plt.bull.2
# This transformation does not appear to have made much difference...

# Examine data distributions
par(mfrow = c(2,2))
hist(bull$area)
hist(log(bull$area))
hist(bull$sbw)
hist(log(bull$sbw))
# The area distribution is left-skewed, with one large outlying value, so using
# a log transform might help to normalise the data and satisfy the underlying
# assumptions of linear model.
bull$area_log <- log(bull$area)

#~~~~~~~~~~~~
# Examine SBW
#~~~~~~~~~~~~

attach(bull)

mod.bull.1 <- lm(sbw ~ area)
mod.bull.2 <- lm(sbw2 ~ area)
mod.bull.3 <- lm(sbw ~ area_log)
mod.bull.4 <- lm(sbw2 ~ area_log)

summary(mod.bull.1)
summary(mod.bull.2)
# The model using raw SBW explains more variability than the model using
# transformed SBW (see adjusted R-squared values).
summary(mod.bull.3)
summary(mod.bull.4)
# Model (3) using log area seems the best, but only marginally so, to keep things
# simple, let's just use model 1 with no transformations.

plot(mod.bull.1) # examine model statistics
# Residuals vs fitted values show no pattern -- good.
# Q-Q plot suggests model residuals are approximately normally distributed -- good

# Extract model output values
out <- summary(mod.bull.1)$coefficients
# The gradient
g <- out[,'Estimate']['area'] # rate of change of SBW with area
pval <- out[,'Pr(>|t|)']['area']
isSignificant <- pval < 0.05
if(isSignificant) print('gradient is significant') else print('gradient is not significant')
if(isSignificant) print(paste('SBW increases linearly by', signif(1e4 * g, 4), 'per 10000 increase in area'))

#~~~~~~~~~~~~
# Examine MBW
#~~~~~~~~~~~~

par(mfrow = c(1,1))
hist(mbw) # appears approximately normally distributed

mod.bull.5 <- lm(mbw ~ area)

summary(mod.bull.5)

par(mfrow = c(2,2))
plot(mod.bull.5) # examine model statistics
# Looks OK

# Extract model output values
out <- summary(mod.bull.5)$coefficients
# The gradient
g <- out[,'Estimate']['area'] # rate of change of MBW with area
pval <- out[,'Pr(>|t|)']['area']
isSignificant <- pval < 0.05
if(isSignificant) print('gradient is significant') else print('gradient is not significant')
if(isSignificant) print(paste('MBW increases linearly by', signif(1e4 * g, 4), 'per 10000 increase in area'))

# These linear models demonstrate that while bulloides SBW increases linearly
# with area, MBW shows no such dependence on area.

detach(bull)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# 2. Incompta

incompta$sbw2 <- incompta$sbw ^ {2/3}

plt.incompta.1 <- ggplot(incompta, aes(x = area, y = sbw)) +
  geom_point()
plt.incompta.2 <- ggplot(incompta, aes(x = area, y = sbw2)) +
  geom_point()

plt.incompta.1
plt.incompta.2
# This transformation does not appear to have made much difference...

# Examine data distributions
par(mfrow = c(2,2))
hist(incompta$area)
hist(log(incompta$area))
hist(incompta$sbw)
hist(log(incompta$sbw))
# The area and SBW both appear to be somewhat close to normally distributed

attach(incompta)

#~~~~~~~~~~~~
# Examine SBW
#~~~~~~~~~~~~

mod.incompta.1 <- lm(sbw ~ area)

summary(mod.incompta.1)

plot(mod.incompta.1) # examine model statistics
# Residuals vs fitted values show no pattern -- good.
# Q-Q plot suggests model residuals are a little skewed
par(mfrow = c(1,1))
hist(mod.incompta.1$residuals) # we can see the skewness here

# Extract model output values
out <- summary(mod.incompta.1)$coefficients
# The gradient
g.1 <- out[,'Estimate']['area'] # rate of change of SBW with area
pval.1 <- out[,'Pr(>|t|)']['area']
isSignificant <- pval.1 < 0.05
if(isSignificant) print('gradient is significant') else print('gradient is not significant')
if(isSignificant) print(paste('SBW increases linearly by', signif(1e4 * g.1, 4), 'per 10000 increase in area'))

#~~~~~~~~~~~~
# Examine MBW
#~~~~~~~~~~~~

par(mfrow = c(1,1))
hist(mbw) # MBW has quite an extreme distribution, shaped like a Cauchy distribution -- expect outlying values in model

mod.incompta.2 <- lm(mbw ~ area)

summary(mod.incompta.2)

par(mfrow = c(2,2))
plot(mod.incompta.2) # examine model statistics
# Outlying values as expected -- see Q-Q plot

# Extract model output values
out <- summary(mod.incompta.2)$coefficients
# The gradient
g.2 <- out[,'Estimate']['area'] # rate of change of MBW with area
pval.2 <- out[,'Pr(>|t|)']['area']
isSignificant <- pval.2 < 0.05
if(isSignificant) print('gradient is significant') else print('gradient is not significant')
if(isSignificant) print(paste('MBW increases linearly by', signif(1e4 * g.2, 4), 'per 10000 increase in area'))

# These linear models demonstrate that, for incompta, SBW increases linearly with
# area while MBW independent of area.

detach(incompta)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# 3. Truncat

truncat$sbw2 <- truncat$sbw ^ {2/3}

plt.truncat.1 <- ggplot(truncat, aes(x = area, y = sbw)) +
  geom_point()
plt.truncat.2 <- ggplot(truncat, aes(x = area, y = sbw2)) +
  geom_point()

plt.truncat.1
plt.truncat.2
# This transformation does not appear to have made much difference...

# Examine data distributions
par(mfrow = c(2,2))
hist(truncat$area)
hist(log(truncat$area))
hist(truncat$sbw)
hist(log(truncat$sbw))
# The area distribution is highly skewed. Log transforms might help to normalise
# the data and satisfy the underlying assumptions of linear model.

truncat$area_log <- log10(truncat$area)

#~~~~~~~~~~~~
# Examine SBW
#~~~~~~~~~~~~

attach(truncat)

mod.truncat.1 <- lm(sbw ~ area)
mod.truncat.2 <- lm(sbw ~ area_log)

summary(mod.truncat.1)
summary(mod.truncat.2)
# Model (3) using log area seems the best, but only marginally so, to keep things
# simple, let's just use model 1 with no transformations.

plot(mod.truncat.1) # examine model statistics
plot(mod.truncat.2) # examine model statistics
# Residuals vs fitted values show upward trend -- some transformation may fix this
# Q-Q plot suggests model residuals are approximately normally distributed -- good
# Residuals vs leverage suggest some points are dominating the model -- not good. Is this related to potential mis-match in data points? SEE NOTE AT TOP OF SCRIPT.

# Extract model output values
out <- summary(mod.truncat.1)$coefficients
# The gradient
g <- out[,'Estimate']['area'] # rate of change of SBW with area
pval <- out[,'Pr(>|t|)']['area']
isSignificant <- pval < 0.05
if(isSignificant) print('gradient is significant') else print('gradient is not significant')
if(isSignificant) print(paste('SBW increases linearly by', signif(1e4 * g, 4), 'per 10000 increase in area'))

#~~~~~~~~~~~~
# Examine MBW
#~~~~~~~~~~~~

par(mfrow = c(1,1))
hist(mbw) # appears approximately normally distributed

mod.truncat.3 <- lm(mbw ~ area)

summary(mod.truncat.3)

par(mfrow = c(2,2))
plot(mod.truncat.3) # examine model statistics
# Residuals vs fitted values -- bit of a downward trend?
# Q-Q plot suggests model residuals are approximately normally distributed -- good
# Residuals vs leverage suggest some points are dominating the model -- not good. Is this related to potential mis-match in data points? SEE NOTE AT TOP OF SCRIPT.

# Extract model output values
out <- summary(mod.truncat.3)$coefficients
# The gradient
g <- out[,'Estimate']['area'] # rate of change of MBW with area
pval <- out[,'Pr(>|t|)']['area']
isSignificant <- pval < 0.05
if(isSignificant) print('gradient is significant') else print('gradient is not significant')
if(isSignificant) print(paste('MBW increases linearly by', signif(1e4 * g, 4), 'per 10000 increase in area'))

# These linear models suggest that, for truncat, SBW increases linearly with area
# while MBW is independent of area.
# However, there the underlying model assumptions are somewhat violated so this
# maybe requires another look... I hope this issue is related to a potential
# mismatch in the data -- see note at top of script.

detach(truncat)





