# Statistical analyses for Béjard et al. (2022); Calcification response of planktic
# foraminifera to environmental change in the Western Mediterranean Sea during the
# industrial era. Coded by Aidan Hunter.
# Assessment of (1) MBW and SBW correlations with area and (2) dependence of MBW
# upon environmental variables.

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Load packages
library(xlsx)      # reading .xlsx data
library(reshape2)  # reshaping data
library(ggplot2)   # plotting
library(GGally)    # correlation plots
library(grid)      # arranging multipanel plots
library(gridExtra) # arranging multipanel plots
library(mgcv)      # GAM analyses
# Save plots and results tables into working directory?
savePlots <- TRUE
saveTables <- TRUE
outDir <- 'output stats' # directory to save output
if(savePlots | saveTables){
  if(!dir.exists(outDir)) dir.create(outDir)}

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# 1. Correlations of MBW and SBW with area
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Load the weight data set
DATA <- read.xlsx('SBW_MBW.xlsx', 1, rowIndex = 1:73)
# Subset data by species
allspecies <- c('bulloides', 'incompta', 'truncatulinoides')
nspecies <- length(allspecies)
bull <- subset(DATA, select = c(Area, SBW.Bulloides, MBW.Bulloides))
incompta <- subset(DATA, select = c(Area.1, SBW.Incompta, MBW.Incompta))
truncat <- subset(DATA, select = c(Area.2, SBW.Truncat, MBW.Truncat))
names(bull) <- c('area','SBW','MBW')
names(incompta) <- c('area','SBW','MBW')
names(truncat) <- c('area','SBW','MBW')
bull$species <- allspecies[1]
incompta$species <- allspecies[2]
truncat$species <- allspecies[3]
# Merge data into long-form
dat <- rbind(bull, incompta, truncat)
dat$species <- factor(dat$species, levels = allspecies)
dat$species_label <- factor(dat$species, labels = c('italic(G.~bulloides)','italic(N.~incompta)','italic(G.~truncatulinoides)'))
dat <- melt(dat, id.vars = c('species','species_label','area'),
            variable.name = 'measure', value.name = 'weight')
# Plot the data
plt1 <- ggplot(data = dat, aes(x = area, y = weight)) + 
  geom_point() + 
  geom_smooth() +
  facet_wrap(vars(measure, species_label), scales = 'free', nrow = 2, labeller = label_parsed) +
  ggtitle('Scatter plots of weight vs area with loess smoothers',
          subtitle = 'Raw weights (SBW) on top row; transformed weights (MBW) on bottom row') +
  xlab(expression('Area' ~ (mu*m^2))) +
  ylab(expression('Weight' ~ (mu*g))) +
  theme_bw()
plt1
#~~~~~~~~~~~~~~~~~~~~~~~~~~
# Pearson correlation tests
#~~~~~~~~~~~~~~~~~~~~~~~~~~
# Generate test values
corrTest <- function(dat, x, y) cor.test(dat[[x]], dat[[y]])
ct_bull_sbw <- corrTest(bull, 'area', 'SBW')
ct_bull_mbw <- corrTest(bull, 'area', 'MBW')
ct_incompta_sbw <- corrTest(incompta, 'area', 'SBW')
ct_incompta_mbw <- corrTest(incompta, 'area', 'MBW')
ct_truncat_sbw <- corrTest(truncat, 'area', 'SBW')
ct_truncat_mbw <- corrTest(truncat, 'area', 'MBW')
# Extract results
getCorr <- function(species){
  sbw <- get(paste0('ct_', species, '_sbw'))
  mbw <- get(paste0('ct_', species, '_mbw'))
  sbw = list(cor = sbw$estimate, confint = as.vector(sbw$conf.int))
  mbw = list(cor = mbw$estimate, confint = as.vector(mbw$conf.int))
  list(sbw = sbw, mbw = mbw)
}
# Correlations
cor_bull_sbw <- getCorr('bull')$sbw$cor
cor_bull_mbw <- getCorr('bull')$mbw$cor
cor_incompta_sbw <- getCorr('incompta')$sbw$cor
cor_incompta_mbw <- getCorr('incompta')$mbw$cor
cor_truncat_sbw <- getCorr('truncat')$sbw$cor
cor_truncat_mbw <- getCorr('truncat')$mbw$cor
# confidence intervals
corRange_bull_sbw <- getCorr('bull')$sbw$confint
corRange_bull_mbw <- getCorr('bull')$mbw$confint
corRange_incompta_sbw <- getCorr('incompta')$sbw$confint
corRange_incompta_mbw <- getCorr('incompta')$mbw$confint
corRange_truncat_sbw <- getCorr('truncat')$sbw$confint
corRange_truncat_mbw <- getCorr('truncat')$mbw$confint
# Store in data frame
corrs <- unique(subset(dat, select = c(species, species_label)))
corrs <- corrs[rep(1:nspecies, each = 2),]
corrs$weight <- rep(c('SBW', 'MBW'), nspecies)
corrs$cor <- c(cor_bull_sbw, cor_bull_mbw, cor_incompta_sbw, cor_incompta_mbw, cor_truncat_sbw, cor_truncat_mbw)
corrs$cor_min <- c(corRange_bull_sbw[1], corRange_bull_mbw[1], corRange_incompta_sbw[1], corRange_incompta_mbw[1], corRange_truncat_sbw[1], corRange_truncat_mbw[1])
corrs$cor_max <- c(corRange_bull_sbw[2], corRange_bull_mbw[2], corRange_incompta_sbw[2], corRange_incompta_mbw[2], corRange_truncat_sbw[2], corRange_truncat_mbw[2])
corrs$significant <- corrs$cor_min > 0 | corrs$cor_max < 0
# Examine results
printOutput <- function(cor, r, species, measure){
  print(paste0('Correlation of ', species, ' ', measure, ' with area is ', signif(cor,2), ' within confidence interval of (', signif(r[1],2), ', ', signif(r[2],2), ').'))
  if(r[1] < 0 & r[2] > 0){
    print('This correlation is not significant.')}else{
      print('This is a significant correlation.')}
}
printOutput(cor_bull_sbw, corRange_bull_sbw, 'Bulloides', 'SBW')
printOutput(cor_bull_mbw, corRange_bull_mbw, 'Bulloides', 'MBW')
printOutput(cor_incompta_sbw, corRange_incompta_sbw, 'Incompta', 'SBW')
printOutput(cor_incompta_mbw, corRange_incompta_mbw, 'Incompta', 'MBW')
printOutput(cor_truncat_sbw, corRange_truncat_sbw, 'Truncat', 'SBW')
printOutput(cor_truncat_mbw, corRange_truncat_mbw, 'Truncat', 'MBW')
print(corrs)

# Include correlation values in plot...
corr_labs <- corrs
nr <- nrow(corr_labs)
corr_labs$species <- factor(corr_labs$species, levels = levels(dat$species))
corr_labs$measure <- factor(corr_labs$weight, levels = levels(dat$measure))
corr_labs$label <- as.character(signif(corr_labs$cor, 2))
corr_labs$xpos <- rep(-Inf, nr)
corr_labs$ypos <- rep(Inf, nr)
corr_labs$hjust = rep(-0.5, nr)
corr_labs$vjust = rep(1.5, nr)
corr_labs$fontface <- ifelse(corr_labs$significant, 'bold', 'plain')
plt1 <- plt1 +
  geom_text(data = corr_labs, aes(x=xpos, y=ypos, label=label, hjust = hjust, vjust = vjust, fontface = fontface))

plt1 + labs(caption = 'Pearson correlation statistics in top left corners: bold values are significant.')

if(savePlots) ggsave(filename = 'weight_vs_area_correlations.png', plot = plt1, device = 'png', path = outDir, width = 12, height = 8, units = 'in')
if(saveTables) write.csv(x = corrs, file = paste(outDir, 'weight_area_correlations.csv', sep = '/'), row.names = FALSE)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# 2. GAMs to assess dependence of MBW upon environmental variables
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Load data on MBW and environmental variables
dat <- read.xlsx('environmental.xlsx', 1, rowIndex = 1:138, colIndex = 1:16)
# View first few rows of data
head(dat)
# Rename columns
names(dat)
orig_names <- names(dat)
names(dat) <- c('date','MBW_bull','MBW_inco','MBW_trun','flux_bull','flux_inco','flux_trun','chl','salinity','sst','nitrates','phosphates','pH','carbonate','DIC','calcium')
# Set date column to class = 'Date'
dat$date <- as.Date(dat$date)
# Create columns for year and month -- we're interested in trends across year
# and seasonal trends within years/across months
l <- strsplit(as.character(dat$date), '-') # split date into components: year, month, day
nr <- nrow(dat) # number of data rows
dat$year <- as.integer(sapply(1:nr, FUN = function(z) l[[z]][1]))
dat$month <- as.integer(sapply(1:nr, FUN = function(z) l[[z]][2]))
# Create three data subsets, one for each species.
bull <- subset(dat, subset = !is.na(MBW_bull), select = -c(MBW_inco, MBW_trun))
inco <- subset(dat, subset = !is.na(MBW_inco), select = -c(MBW_bull, MBW_trun))
trun <- subset(dat, subset = !is.na(MBW_trun), select = -c(MBW_bull, MBW_inco))
names(bull)[names(bull) == 'MBW_bull'] = 'MBW'
names(trun)[names(trun) == 'MBW_trun'] = 'MBW'
names(inco)[names(inco) == 'MBW_inco'] = 'MBW'
# Correlation plots of all the data (uses GGally package)
corPlots <- function(species){
  d <- get(species)
  lab <- switch(species,
                bull = 'Correlations: bulloides MBW',
                trun = 'Correlations: incompta MBW',
                inco = 'Correlations: truncatulinoides MBW')
  plt <- ggpairs(data = subset(d, select = - date)) + 
    ggtitle(lab) +
    theme_bw() +
    theme(axis.line = element_line(colour = "black"),
          panel.grid.major = element_blank(),
          panel.grid.minor = element_blank(),
          panel.border = element_blank(),
          panel.background = element_blank()) 
  plt
}
b_cor_plt <- corPlots('bull')
i_cor_plt <- corPlots('inco')
t_cor_plt <- corPlots('trun')
# b_cor_plt
# i_cor_plt
# t_cor_plt
# if(savePlots){
#   ggsave('bulloides_correlationPlot.png', b_cor_plt, units = 'in', width = 20, height = 14)
#   ggsave('incompta_correlationPlot.png', i_cor_plt, units = 'in', width = 20, height = 14)
#   ggsave('truncatulinoides_correlationPlot.png', t_cor_plt, units = 'in', width = 20, height = 14)
# }
# Transform data into long format
bull_long <- melt(bull, id.vars = c('date', 'MBW'))
inco_long <- melt(inco, id.vars = c('date', 'MBW'))
trun_long <- melt(trun, id.vars = c('date', 'MBW'))
# Plot the potential explanatory variables against time
environ <- subset(bull_long, !variable %in% c('year','month'))
col <- 'hotpink'
plotFunction_1 <- function(data = environ, method = NULL){
  switch (method,
          gam = {
            formula = y ~ s(x, bs = 'tp')
            Method = 'GAM'},
          loess = {
            formula = NULL
            Method = 'loess'}
  )
  plt <- ggplot(data = data, aes(x = date, y = value)) +
    geom_point() + 
    geom_smooth(colour = col, fill = col,
                method = method) +
    facet_wrap(~ variable, scales = 'free') + 
    labs(title = paste('Explanatory variables vs time:', Method, 'smoother')) +
    xlab('Date') + 
    ylab(element_blank()) +
    theme_bw()
  plt
}
plt_vars_gam <- plotFunction_1(data = environ, method = 'gam')
plt_vars_loess <- plotFunction_1(data = environ, method = 'loess')
plt_vars_gam
plt_vars_loess
# GAMs cannot be fitted to the carbonate system data because there are too
# few data points. We need a different method to fit a smoothing curve through
# these data -- loess polynomials should work.
# Plot MBW against all potential explanatory variables and overlay GAM model output.
relabel <- setNames(c(
  'italic(G.~bulloides)~flux~(indiv/m^2/day)', 'italic(N.~incompta)~flux~(indiv/m^2/day)', 'italic(G.~truncatulinoides)~flux~(indiv/m^2/day)',
  'chlorophyll~a~(mg/m^3)', 'salinity~(psu)', 's.s.t.~(degree*C)', 'nitrate~(mu*mol/kg~SW)',
  'phosphate~(mu*mol/kg~SW)', 'pH', 'carbonate~(mu*mol/kg~SW)', 'DIC~(mu*mol/kg~SW)',
  'Omega*Ca', 'year', 'month'), levels(environ$variable))
bull_long$variable <- factor(bull_long$variable, labels = relabel)
inco_long$variable <- factor(inco_long$variable, labels = relabel)
trun_long$variable <- factor(trun_long$variable, labels = relabel)

col_gam <- 'forestgreen'
col_loess <- 'dodgerblue'
alph <- 0.35 # transparency of confidence intervals (1 = solid, 0 = invisible)
plotFunction_2 <- function(data, species, method = 'gam'){
  switch (method,
          gam = {
            col = col_gam
            formula = y ~ s(x, bs = 'tp')
            Method = 'GAM'},
          loess = {
            col = col_loess
            formula = NULL
            Method = 'loess'}
  )
  title_ <- switch(species,
                  Bulloides = 'G. bulloides',
                  Incompta = 'N. incompta',
                  Truncatulinoides = 'G. truncatulinoides'
                  )
  plt <- ggplot(data = data, aes(x = value, y = MBW)) +
    geom_point() +
    geom_smooth(method = method, formula = formula,
                colour = col, fill = col, alpha = alph) +
    facet_wrap(~ variable, scales = 'free_x', labeller = label_parsed) +
    labs(title = bquote(italic(.(title_)) ~ 'MBW vs potential explanatory variables:' ~ .(Method) ~ 'smoother')) +
    xlab(element_blank()) +
    ylab(paste(species, 'MBW')) +
    theme_bw()
  plt
}
plt_bull_gam <- plotFunction_2(bull_long, 'Bulloides', method = 'gam')
plt_trun_gam <- plotFunction_2(trun_long, 'Truncatulinoides', method = 'gam')
plt_inco_gam <- plotFunction_2(inco_long, 'Incompta', method = 'gam')
plt_bull_loess <- plotFunction_2(bull_long, 'Bulloides', method = 'loess')
plt_trun_loess <- plotFunction_2(trun_long, 'Truncatulinoides', method = 'loess')
plt_inco_loess <- plotFunction_2(inco_long, 'Incompta', method = 'loess')
# Bulloides
plt_bull_gam
plt_bull_loess
# Incompta
plt_inco_gam
plt_inco_loess
# Truncatulinoides
plt_trun_gam
plt_trun_loess

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Use mgcv package to create GAMs
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
allVariables <- names(bull)[3:ncol(bull)]
nVariables <- length(allVariables)
# Fit GAMs
fit_GAM <- function(data, v){
  # function defining single-variable GAM
  x <- unname(unlist(data[v]))
  y <- data$MBW
  try(gam(y ~ s(x)), silent = TRUE)}
# Get p-values from fitted models
extract_pvals <- function(mod){
  ifelse(class(mod)[1] != 'try-error', summary(mod)$s.pv, NA)}
# Test for significant relationship between MBW and explanatory variables
isSignificant <- function(pval) pval < 0.05

# 1. Bulloides
plt_bull_loess
# b_cor_plt # correlation plot
# Loop through all explanatory variables, fit GAM to each variable and extract
# p-values to assess significance of variable upon MBW.
for(i in 1:nVariables){
  v <- allVariables[i]
  mod <- fit_GAM(bull, v) # the model
  modName <- paste0('mod_bull_', v)
  assign(modName, mod)
  pval <- extract_pvals(mod)
  pvalName <- paste0('mod_bull_', v, '_pval')
  assign(pvalName, pval)
  sig <- isSignificant(pval)
  sigName <- paste0('mod_bull_', v, '_significant')
  assign(sigName, sig)
  rm(list = c('mod', 'pval', 'sig'))
}
# Display results
GAM_results_bull <- setNames(as.data.frame(t(sapply(1:nVariables, function(z){
  v <- allVariables[z]
  mod <- get(paste('mod_bull', v, sep = '_'))
  if(class(mod)[1] != 'try-error'){
    p <- get(paste('mod_bull', v, 'pval', sep = '_'))
    s <- get(paste('mod_bull', v, 'significant', sep = '_'))
    c(v,p,s)
  }else{
    c(v, NA, NA)
  }
}))), c('variable','p_value','significant'))
GAM_results_bull$p_value     <- as.numeric(GAM_results_bull$p_value)
GAM_results_bull$significant <- as.logical(GAM_results_bull$significant)
GAM_results_bull

# 2. Incompta
plt_inco_loess
# i_cor_plt # correlation plot
for(i in 1:nVariables){
  v <- allVariables[i]
  mod <- fit_GAM(inco, v) # the model
  modName <- paste0('mod_inco_', v)
  assign(modName, mod)
  pval <- extract_pvals(mod)
  pvalName <- paste0('mod_inco_', v, '_pval')
  assign(pvalName, pval)
  sig <- isSignificant(pval)
  sigName <- paste0('mod_inco_', v, '_significant')
  assign(sigName, sig)
  rm(list = c('mod', 'pval', 'sig'))
}
# Display results
GAM_results_inco <- setNames(as.data.frame(t(sapply(1:nVariables, function(z){
  v <- allVariables[z]
  mod <- get(paste('mod_inco', v, sep = '_'))
  if(class(mod)[1] != 'try-error'){
    p <- get(paste('mod_inco', v, 'pval', sep = '_'))
    s <- get(paste('mod_inco', v, 'significant', sep = '_'))
    c(v,p,s)
  }else{
    c(v, NA, NA)
  }
}))), c('variable','p_value','significant'))
GAM_results_inco$p_value     <- as.numeric(GAM_results_inco$p_value)
GAM_results_inco$significant <- as.logical(GAM_results_inco$significant)
GAM_results_inco

# 3. Truncatulinoides
plt_trun_loess
# t_cor_plt # correlation plot
for(i in 1:nVariables){
  v <- allVariables[i]
  mod <- fit_GAM(trun, v) # the model
  modName <- paste0('mod_trun_', v)
  assign(modName, mod)
  pval <- extract_pvals(mod)
  pvalName <- paste0('mod_trun_', v, '_pval')
  assign(pvalName, pval)
  sig <- isSignificant(pval)
  sigName <- paste0('mod_trun_', v, '_significant')
  assign(sigName, sig)
  rm(list = c('mod', 'pval', 'sig'))
}
# Display results
GAM_results_trun <- setNames(as.data.frame(t(sapply(1:nVariables, function(z){
  v <- allVariables[z]
  mod <- get(paste('mod_trun', v, sep = '_'))
  if(class(mod)[1] != 'try-error'){
    p <- get(paste('mod_trun', v, 'pval', sep = '_'))
    s <- get(paste('mod_trun', v, 'significant', sep = '_'))
    c(v,p,s)
  }else{
    c(v, NA, NA)
  }
}))), c('variable','p_value','significant'))
GAM_results_trun$p_value     <- as.numeric(GAM_results_trun$p_value)
GAM_results_trun$significant <- as.logical(GAM_results_trun$significant)
GAM_results_trun

# View all results
GAM_results <- rbind(
  cbind(species = 'bulloides', GAM_results_bull),
  cbind(species = 'incompta', GAM_results_inco),
  cbind(species = 'truncatulinoides', GAM_results_trun))

print(GAM_results)

# Include p-values (significance indicators) in the plots
annotation_info <- function(species){
  gr <- get(paste0('GAM_results_', species))
  pv <- as.character(signif(gr$p_value, 2))
  pv[is.na(pv)] = ''
  ff <- sapply(gr$significant, function(z) ifelse(z, 'bold', 'plain'))
  ff[is.na(ff)] = 'plain'
  lab <- data.frame(
    variable = allVariables,
    xpos = rep(-Inf, nVariables),
    ypos = rep(Inf, nVariables),
    text = pv,
    fontface = ff,
    hjust = rep(-0.5, nVariables),
    vjust = rep(1.5, nVariables)
  )
  lab$variable <- factor(lab$variable, levels = allVariables, labels = relabel[allVariables])
  lab}
lab_bull <- annotation_info('bull')
lab_inco <- annotation_info('inco')
lab_trun <- annotation_info('trun')
# Update plots
plt_bull_gam <- plt_bull_gam +
  geom_text(data = lab_bull, aes(x=xpos, y=ypos, label=text, hjust = hjust, vjust = vjust, fontface = fontface))
plt_trun_gam <- plt_trun_gam +
  geom_text(data = lab_trun, aes(x=xpos, y=ypos, label=text, hjust = hjust, vjust = vjust, fontface = fontface))
plt_inco_gam <- plt_inco_gam +
  geom_text(data = lab_inco, aes(x=xpos, y=ypos, label=text, hjust = hjust, vjust = vjust, fontface = fontface))
cap <- expression('Model p-values in top left corner: significant (p' < 0.05 * ') variables indicated in' ~ bold('bold') * '.')

plt_bull_gam + labs(caption = cap)
plt_trun_gam + labs(caption = cap)
plt_inco_gam + labs(caption = cap)

if(savePlots){
  ggsave(filename = 'MBW_bulloides vs all vars_GAM.png', plot = plt_bull_gam, device = 'png', path = outDir, width = 12, height = 8, units = 'in')
  ggsave(filename = 'MBW_incompta vs all vars_GAM.png', plot = plt_inco_gam, device = 'png', path = outDir, width = 12, height = 8, units = 'in')
  ggsave(filename = 'MBW_truncatulinoides vs all vars_GAM.png', plot = plt_trun_gam, device = 'png', path = outDir, width = 12, height = 8, units = 'in')
}

# Save GAM results as table
write.csv(x = GAM_results, file = paste(outDir, 'GAM results.csv', sep = '/'), row.names = FALSE)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# 3. Extra plots
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# bulloides
col <- 'blue'
yl <- expression(italic(G.~bulloides) ~ MBW ~ (mu * g))

plt_by <- ggplot(data = bull, aes(x = year, y = MBW)) +
  geom_point() +
  geom_smooth(method = 'gam', formula = y ~ s(x, bs = 'tp'),
              colour = col, fill = col, alpha = alph) +
  scale_x_continuous(breaks = min(bull$year):max(bull$year)) +
  xlab(element_blank()) +
  ylab(yl) +
  theme_bw()

plt_bm <- ggplot(data = bull, aes(x = month, y = MBW)) +
  geom_point() +
  geom_smooth(method = 'gam', formula = y ~ s(x, bs = 'tp'),
              colour = col, fill = col, alpha = alph) +
  scale_x_continuous(breaks = min(bull$month):max(bull$month), labels = month.abb) +
  xlab(element_blank()) +
  ylab(yl) +
  theme_bw()

# incompta
col <- 'black'
yl <- expression(italic(N.~incompta) ~ MBW ~ (mu * g))
  
plt_iy <- ggplot(data = inco, aes(x = year, y = MBW)) +
  geom_point() +
  geom_smooth(method = 'gam', formula = y ~ s(x, bs = 'tp'),
              colour = col, fill = col, alpha = alph) +
  scale_x_continuous(breaks = min(inco$year):max(inco$year)) +
  xlab(element_blank()) +
  ylab(yl) +
  theme_bw()

plt_im <- ggplot(data = inco, aes(x = month, y = MBW)) +
  geom_point() +
  geom_smooth(method = 'gam', formula = y ~ s(x, bs = 'tp'),
              colour = col, fill = col, alpha = alph) +
  scale_x_continuous(breaks = min(inco$month):max(inco$month), labels = month.abb) +
  xlab(element_blank()) +
  ylab(yl) +
  theme_bw()

# truncatulinoides
col <- 'red'
yl <- expression(italic(G.~truncatulinoides) ~ MBW ~ (mu * g))

plt_ty <- ggplot(data = trun, aes(x = year, y = MBW)) +
  geom_point() +
  geom_smooth(method = 'gam', formula = y ~ s(x, bs = 'tp'),
              colour = col, fill = col, alpha = alph) +
  scale_x_continuous(breaks = min(trun$year):max(trun$year)) +
  xlab(element_blank()) +
  ylab(yl) +
  theme_bw()

plt_tm <- ggplot(data = trun, aes(x = month, y = MBW)) +
  geom_point() +
  geom_smooth(method = 'gam', formula = y ~ s(x, bs = 'tp'),
              colour = col, fill = col, alpha = alph) +
  scale_x_continuous(breaks = min(trun$month):max(trun$month), labels = month.abb) +
  xlab(element_blank()) +
  ylab(yl) +
  theme_bw()

# merge the plots  
pltTitle_b <- textGrob(expression(italic(G.~bulloides)~'MBW interannual & seasonal trends'))
pltTitle_i <- textGrob(expression(italic(N.~incompta)~'MBW interannual & seasonal trends'))
pltTitle_t <- textGrob(expression(italic(G.~truncatulinoides)~'MBW interannual & seasonal trends'))
plt_b <- grid.arrange(plt_by,
                      plt_bm + theme(axis.title.y = element_blank()),
                      ncol = 2, top = pltTitle_b)
plt_i <- grid.arrange(plt_iy,
                      plt_im + theme(axis.title.y = element_blank()),
                      ncol = 2, top = pltTitle_i)
plt_t <- grid.arrange(plt_ty,
                      plt_tm + theme(axis.title.y = element_blank()),
                      ncol = 2, top = pltTitle_t)

if(savePlots){
  ggsave(filename = 'MBW_bulloides temporal trends.png', plot = plt_b, device = 'png', path = outDir, width = 12, height = 8, units = 'in')
  ggsave(filename = 'MBW_incompta temporal trends.png', plot = plt_i, device = 'png', path = outDir, width = 12, height = 8, units = 'in')
  ggsave(filename = 'MBW_truncatulinoides temporal trends.png', plot = plt_t, device = 'png', path = outDir, width = 12, height = 8, units = 'in')
}
